@@ -28,16 +28,86 @@ exports qw{
         CAN_SET_SUB_NAME
         sub_info
         sub_name
+        rename_anon_sub
+
+        update_mask
 };
 no Test::Stream::Exporter;
 
+BEGIN {
+    local ($@, $!, $SIG{__DIE__});
+    my $have_sub_util = eval { require Sub::Util; 1 };
+    my $have_sub_name = eval { require Sub::Name; 1 };
+
+    my $set_subname = $have_sub_util ? Sub::Util->can('set_subname') : undef;
+    my $subname     = $have_sub_name ? Sub::Name->can('subname')     : undef;
+
+    *set_sub_name = $set_subname || $subname || sub { croak "Cannot set sub name" };
+
+    if($set_subname || $subname) {
+        *CAN_SET_SUB_NAME = sub() { 1 };
+    }
+    else {
+        *CAN_SET_SUB_NAME = sub() { 0 };
+    }
+}
+
+sub sub_name {
+    my ($sub) = @_;
+
+    croak "sub_name requires a coderef as its only argument"
+        unless $sub && ref($sub) && reftype($sub) eq 'CODE';
+
+    my $cobj = B::svref_2object($sub);
+    my $name = $cobj->GV->NAME;
+    return $name;
+}
+
+sub rename_anon_sub {
+    my ($name, $sub, $caller) = @_;
+    $caller ||= caller();
+
+    croak "sub_name requires a coderef as its second argument"
+        unless $sub && ref($sub) && reftype($sub) eq 'CODE';
+
+    my $cobj = B::svref_2object($sub);
+    my $orig = $cobj->GV->NAME;
+    return unless $orig =~ m/__ANON__$/;
+    set_sub_name("${caller}::${name}", $sub);
+}
+
+sub update_mask {
+    my ($file, $line, $name, $mask) = @_;
+
+    no warnings 'once';
+    my $masks = \%Trace::Mask::MASKS;
+    use warnings 'once';
+
+    # Get existing ref, if any
+    my $ref = $masks->{$file}->{$line}->{$name};
+
+    # No ref, easy!
+    return $masks->{$file}->{$line}->{$name} = {%$mask}
+        unless $ref;
+
+    # Merge new mask into old
+    %$ref = (%$ref, %$mask);
+    return;
+}
+
 sub _manual_protect(&) {
     my $code = shift;
 
+    rename_anon_sub('protect', $code, caller) if CAN_SET_SUB_NAME;
+
     my ($ok, $error);
     {
         my ($msg, $no) = ($@, $!);
-        $ok = eval { $code->(); 1 } || 0;
+        $ok = eval {
+            BEGIN { update_mask(__FILE__, __LINE__ + 1, '*', {hide => 3}) }
+            $code->();
+            1
+        } || 0;
         $error = $@ || "Error was squashed!\n";
         ($@, $!) = ($msg, $no);
     }
@@ -48,10 +118,16 @@ sub _manual_protect(&) {
 sub _local_protect(&) {
     my $code = shift;
 
+    rename_anon_sub('protect', $code, caller) if CAN_SET_SUB_NAME;
+
     my ($ok, $error);
     {
         local ($@, $!);
-        $ok = eval { $code->(); 1 } || 0;
+        $ok = eval {
+            BEGIN { update_mask(__FILE__, __LINE__ + 1, '*', {hide => 3}) }
+            $code->();
+            1
+        } || 0;
         $error = $@ || "Error was squashed!\n";
     }
     die $error unless $ok;
@@ -64,11 +140,17 @@ sub _manual_try(&;@) {
     my $error;
     my $ok;
 
+    rename_anon_sub('try', $code, caller) if CAN_SET_SUB_NAME;
+
     {
         my ($msg, $no) = ($@, $!);
         my $die = delete $SIG{__DIE__};
 
-        $ok = eval { $code->(@$args); 1 } || 0;
+        $ok = eval {
+            BEGIN { update_mask(__FILE__, __LINE__ + 1, '*', {hide => 3}) }
+            $code->(@$args);
+            1
+        } || 0;
         unless($ok) {
             $error = $@ || "Error was squashed!\n";
         }
@@ -91,9 +173,15 @@ sub _local_try(&;@) {
     my $error;
     my $ok;
 
+    rename_anon_sub('try', $code, caller) if CAN_SET_SUB_NAME;
+
     {
         local ($@, $!, $SIG{__DIE__});
-        $ok = eval { $code->(@$args); 1 } || 0;
+        $ok = eval {
+            BEGIN { update_mask(__FILE__, __LINE__ + 1, '*', {hide => 3}) }
+            $code->(@$args);
+            1
+        } || 0;
         unless($ok) {
             $error = $@ || "Error was squashed!\n";
         }
@@ -225,34 +313,6 @@ sub render_ref {
     return "$class=$ref";
 }
 
-BEGIN {
-    my ($have_sub_util) = try { require Sub::Util };
-    my ($have_sub_name) = try { require Sub::Name };
-
-    my $set_subname = $have_sub_util ? Sub::Util->can('set_subname') : undef;
-    my $subname     = $have_sub_name ? Sub::Name->can('subname')     : undef;
-
-    *set_sub_name = $set_subname || $subname || sub { croak "Cannot set sub name" };
-
-    if($set_subname || $subname) {
-        *CAN_SET_SUB_NAME = sub() { 1 };
-    }
-    else {
-        *CAN_SET_SUB_NAME = sub() { 0 };
-    }
-}
-
-sub sub_name {
-    my ($sub) = @_;
-
-    croak "sub_name requires a coderef as its only argument"
-        unless $sub && ref($sub) && reftype($sub) eq 'CODE';
-
-    my $cobj = B::svref_2object($sub);
-    my $name = $cobj->GV->NAME;
-    return $name;
-}
-
 sub sub_info {
     my ($sub, @all_lines) = @_;
     my %in = map {$_ => 1} @all_lines;
@@ -494,6 +554,11 @@ line fields, these have not been adjusted for you.
 
 =back
 
+=item update_mask($file, $line, $sub, {...})
+
+This sets masking behavior in accordance with L<Trace::Mask>. This will have no
+effect on anything that does not honor L<Trace::Mask>.
+
 =back
 
 =head1 SOURCE
